<?php

session_start();

require dirname(__FILE__) . "/includes/config.inc.php";

$showResetForm = false; // si true, le champ mot de passe s'affichera.

/*
 * L'utilisateur a cliqué le lien du mail pour réinitaliser son mot de passe.
 * Nous regardons si le token est bien le même suivant la base de données.
 */

if (isset($_GET['token'])) {
    Tools::escapeDataToSql($_GET['token']);
    $db = SiteSQL::getInstance();
    $isCorrect = $db->getAll("SELECT * FROM back_administrateur WHERE administrateur_token = '{$_GET['token']}';");

    if (!isset($isCorrect[0]['administrateur_token'])) $errorMsg = 'Le token ne correspond pas ou est vide. Merci de réessayer en renvoyant un formulaire de réinitalisation.';
    else $showResetForm = true;
}

if (!empty($_POST)) {

    Tools::escapeDataToSql($_POST);
    $db = SiteSQL::getInstance();
    $droit = new BackDroit();

    $errorMsg = '';

    $isHere = false;
    foreach ($_POST as $k => $p) {
        if (in_array($k, array('administrateur_id', 'administrateur_email'))) {
            $isHere = true;
            break;
        }
    }

    if (!$isHere) { // administrateur_id ou administrateur_email n'a pas été trouvé dans $_POST.
        $errorMsg = 'Une erreur est survenue, merci de réessayer plus tard.';
    }

    if (empty($errorMsg)) {
        // Demande de réinitalisation du mot de passe.
        if (isset($_POST['administrateur_email'])) {

            // Si le compte n'est pas administrateur, on retourne une erreur.
            if (!$arrAdmin = $droit->isAdministrateur($_POST)) {
                $errorMsg = 'Cet utilisateur n\'est pas administrateur.';
            }

            // Pas d'erreur, on peut continuer sagement.
            if (empty($errorMsg)) {
                $tokenToSave = Tools::getRand(16);
                $link = BACK_URL . 'forgotten.php?token=' . $tokenToSave;

                try {
                    $db->beginTransaction();
                    $db->query("UPDATE back_administrateur SET administrateur_token = '{$tokenToSave}' WHERE administrateur_id = '{$arrAdmin[0]['administrateur_id']}';");
                    $mailer = Application::getEmailSender();
                    $mailer->send(EmailSender::createMessage($_POST['administrateur_email'], 'Récupération de mot de passe', 'Pour récupèrer votre mot de passe, veuillez trouver un lien de réinitialisation: <a href="' . $link . '">' . $link . '</a>'));
                    $db->endTransaction();
                    $successMsg = 'Un mail de réinitialisation a été envoyé sur votre adresse. Veuillez suivre les instructions données.';
                } catch (Exception $e) {
                    $db->db->rollback();
                    error_log($e->getMessage());
                    error_log($e->getTraceAsString());
                    $errorMsg = 'Une erreur s\'est produite. Merci de réessayer plus tard.';
                }
            }
        }
        // Si on trouve 'administrateur_newpass' et 'administrateur_newpass_confirm' dans $_POST, l'utilisateur est entrain de changer son mot de passe.
        if (isset($_POST['administrateur_newpass'], $_POST['administrateur_newpass_confirm'])) {
            //Si le mot de passe actuel/confirmation sont vides, on retourne une erreur.
            if (empty($_POST['administrateur_newpass']) || empty($_POST['administrateur_newpass_confirm'])) {
                $errorMsg = 'Le mot de passe actuel et le mot de passe de confirmation ne doivent pas être vide.';
            }

            if (empty($errorMsg)) {
                $getEmail = $db->getAll("SELECT * FROM back_administrateur WHERE administrateur_id = '{$_POST['administrateur_id']}';");

                // Si l'adresse email saisie n'existe pas, ou si le compte n'est pas administrateur, on retourne une erreur.
                if (!isset($getEmail[0]['administrateur_email']) || !$arrAdmin = $droit->isAdministrateur($getEmail[0])) {
                    $errorMsg = 'Cet utilisateur n\'existe pas ou n\'est pas administrateur.';
                }

                // Si le mot de passe actuel ne correspond pas avec le mot de passe de confirmation, on réessaye de nouveau.
                if ($_POST['administrateur_newpass_confirm'] != $_POST['administrateur_newpass']) {
                    $link = "/back/forgotten.php?token={$arrAdmin[0]['administrateur_token']}";
                    $errorMsg = 'Les mots de passe ne correspondent pas. Pour retenter, merci de vous rediriger <a href="' . $link . '">ici</a>';
                }

                // On sauvegarde le tout en base de données, sinon on revert les changements et on retourne une erreur.
                if (empty($errorMsg)) {
                    try {
                        $db->beginTransaction();
                        $db->query("UPDATE back_administrateur SET administrateur_password = '" . Tools::encryptPassword($_POST['administrateur_newpass']) . "', administrateur_token = '' WHERE administrateur_id = '{$arrAdmin[0]['administrateur_id']}';");
                        $mailer = Application::getEmailSender();
                        $mailer->send(EmailSender::createMessage($getEmail[0]['administrateur_email'], 'Changement de mot de passe', 'Un changement de mot de passe a été effectué le ' . date('d M Y \à h:i:s') . '.'));
                        $db->endTransaction();
                        $successMsg = 'Votre mot de passe a bien été changé. Un mail de confirmation a été envoyé sur votre adresse email. Vous pouvez maintenant vous <a href="/back/">connecter</a> avec votre nouveau mot de passe.';
                    } catch (Exception $e) {
                        $db->db->rollback();
                        error_log($e->getMessage());
                        error_log($e->getTraceAsString());
                        $errorMsg = 'Une erreur s\'est produite. Merci de réessayer plus tard.';
                    }
                }
            }
        }
    }
}

include(dirname(__FILE__) . "/includes/header.inc.php");

?>

    <div class="login-box">
        <div class="login-logo">
            <a href="index.php">Shop by Dedi</a>
        </div>
        <!-- /.login-logo -->
        <div class="login-box-body">
            <p class="login-box-msg"><?= ($showResetForm ? "Changement du mot de passe pour <span style=\"font-weight:bold;\"> " . $isCorrect[0]['administrateur_email'] . " </span>" : "Récupération de mot de passe"); ?></p>
            <?php if ((!empty($successMsg)) || (!empty($errorMsg))) : ?>
                <div class="alert alert-<?= (!empty($errorMsg) ? 'danger' : 'success'); ?> alert-dismissible text-center">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                    <?= (!empty($errorMsg) ? $errorMsg : $successMsg); ?>
                </div>
            <?php endif; ?>
            <form action="forgotten.php" method="post">
                <?php if ($showResetForm == false): ?>
                    <div class="form-group <?php if(isset($error) && !empty($error)) echo 'has-error'; ?> has-feedback">
                        <input type="email" class="form-control" name="administrateur_email" placeholder="Email" autofocus>
                        <span class="glyphicon glyphicon-envelope form-control-feedback"></span>
                        <?php
                        if(isset($error) && !empty($error)) echo '<p class="help-block">' . $error . '</p>';
                        ?>

                    </div>
                <?php else: ?>
                    <input type="hidden" name="administrateur_id" id="administrateur_id" value="<?= $isCorrect[0]['administrateur_id']; ?>"/>
                    <div class="form-group has-feedback">
                        <input type="password" class="form-control" name="administrateur_newpass" autofocus required>
                        <span class="glyphicon glyphicon-lock form-control-feedback"></span>
                    </div>
                    <div class="form-group has-feedback">
                        <input type="password" class="form-control" name="administrateur_newpass_confirm" autofocus required>
                        <span class="glyphicon glyphicon-lock form-control-feedback"></span>
                    </div>
                <?php endif; ?>
                <div class="row">
                    <!-- /.col -->
                    <div class="col-xs-4 col-xs-offset-8">
                        <button type="submit" class="btn btn-primary btn-block btn-flat">Envoyer</button>
                    </div>
                    <!-- /.col -->
                </div>
            </form>

        </div>
        <!-- /.login-box-body -->
    </div>
    <!-- /.login-box -->

<?php

include(dirname(__FILE__) . "/includes/footer.inc.php");