<?php

namespace Controller;

use Form\NewsletterForm;
use Symfony\Component\Routing\Annotation\Route;
use Newsletter;
use Boutique;
use Texte;

/**
 * class NewsletterController
 *
 * @package Controller
 *
 * @Route(path = "/newsletter")
 */
class NewsletterController extends Controller
{

    /**
     * Function call when someone want to subscribe to the newsletter
     *
     * @Route("/subscribe", name="newsletter_subscribe")
     *
     * @return \Symfony\Component\HttpFoundation\Response
     *
     * @throws \DediException
     */
    public function subscribe()
    {
        $form = new NewsletterForm();
        $newsletter = new Newsletter();
        $json = array();

        $flashBag = $this->getFlashBag();

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
        }

        if ($flashBag->has("error") == false) {
            $boutique = Boutique::getInstance();

            $data = [
                'newsletter_email' => $this->request->get('email'),
                'boutique_id' => $boutique->id,
                'langue_id' => $boutique->getLangue()->id,
            ];

            if ($this->request->get('type') != false) {
                $data['newsletter_type_id'] = $this->request->get('type');
            }

            $id = $newsletter->save($data);

            $json['url'] = $this->generateUrl('newsletter_success');
            $flashBag->set("newsletter_id", $id);
        } else {
            $json['url'] = $this->generateUrl('newsletter_error');
        }

        return $this->response($json);
    }

    /**
     * @Route("/success", name="newsletter_success")
     */
    public function resultSuccess()
    {

        $texte = new Texte();
        $flashBag = $this->getFlashBag();

        $tplVars['success'] = $texte->getOneOrCreate(
            'newsletter_sub_success',
            'Vous êtes maintenant inscris à notre newsletter'
        );

        $newsletter = new Newsletter();
        if ($flashBag->has('newsletter_id')) {
            $newsletter->load(current($flashBag->get('newsletter_id')));
            $tplVars['newsletter'] = $newsletter->toArray();
        }

        /*if (empty($newsletter->newsletter_type_id)) {
            $tplVars['types'] = $newsletter->getType();
        }*/

        return $this->fetch('newsletter/subscribe.tpl', $tplVars);
    }

    /**
     * @Route("/error", name="newsletter_error")
     */
    public function resultError()
    {
        $flashBag = $this->getFlashBag();
        $tplVars = array();

        if ($flashBag->has('error')) {
            $tplVars['error'] = $flashBag->get('error');
        }

        $newsletter = new Newsletter();
        if ($flashBag->has('newsletter_id')) {
            $newsletter->load(current($flashBag->get('newsletter_id')));
            $tplVars['newsletter'] = $newsletter->toArray();
        }

        // $tplVars['types'] = $newsletter->getType();

        return $this->fetch('newsletter/subscribe.tpl', $tplVars);
    }

    /**
     * @Route("/unsubscribe", name="newsletter_unsubscribe")
     */
    public function unsubscribe()
    {
        $form = new NewsletterForm();
        $newsletter = new Newsletter();
        $texte = new Texte();
        $json = array();

        $flashBag = $this->getFlashBag();

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
        }

        $sub = $newsletter->get(
            ['newsletter_email' => $this->request->get('email')]
        );

        if (empty($sub)) {
            $flashBag->add(
                "error",
                $texte->getOneOrCreate(
                    'no_subscribe',
                    'Vous n\'êtes pas inscris à la newsletter'
                )
            );
        }

        if ($flashBag->has("error") == false) {

            $newsletter->save(
                ['newsletter_id' => $sub[0]['newsletter_id'],
                'newsletter_unsubscribe' => date('Y-m-d H:i:s')]
            );

            $json['url'] = $this->generateUrl('newsletter_success');
        } else {
            $json['url'] = $this->generateUrl('newsletter_error');
        }

        return $this->response($json);
    }

    /**
     * @Route("/select-type", name="newsletter_select_type")
     */
    public function selectType()
    {
        $texte = new Texte();
        $json = array();

        $flashBag = $this->getFlashBag();

        if ($this->request->get('newsletter_id') == false) {
            $flashBag->add(
                'error',
                $texte->getOneOrCreate(
                    'no_newsletter_id',
                    'Erreur lors de la selection. Veuillez recommencé'
                )
            );
        }

        if ($this->request->get('type') == false) {
            $flashBag->add(
                'error',
                $texte->getOneOrCreate(
                    'no_newsletter_type',
                    'Vous devez selectionner un des choix proposé ci-dessous'
                )
            );
        }

        if ($flashBag->has("error") == false) {
            $newsletter = new Newsletter($this->request->get('newsletter_id'));
            $newsletter->newsletter_type_id = $this->request->get('type');
            $id = $newsletter->save();
            $flashBag->set("newsletter_id", $id);

            $json['url'] = $this->generateUrl('newsletter_success');
        } else {
            $json['url'] = $this->generateUrl('newsletter_error');
        }

        return $this->response($json);
    }

}