<?php

/**
 * Class EmailSender
 */
class EmailSender {

    /**
     * @var Swift_Transport
     */
    protected $transport;

    /**
     * @var Swift_Mailer
     */
    protected $mailer;

    /**
     * @var Swift_Plugins_Logger
     */
    protected $logger;

    public function __construct(Swift_Transport $transport, Swift_Plugins_Logger $logger = null)
    {
        $this->transport = $transport;
        $this->logger = (is_null($logger)) ? new Swift_Plugins_Loggers_ArrayLogger() : $logger;
        $this->mailer = Swift_Mailer::newInstance($transport);
        $this->mailer->registerPlugin(new Swift_Plugins_LoggerPlugin($this->logger));
    }

    /**
     * @param Swift_Message $message
     * @return int
     */
    public function send(Swift_Message $message)
    {
        $result = $this->mailer->send($message);

        error_log($this->logger->dump());

        return $result;
    }

    /**
     * @return Swift_Plugins_Logger
     */
    public function getLogger()
    {
        return $this->logger;
    }

    /**
     * @param $to
     * @param $subject
     * @param $body
     * @param null $from
     * @param array $files
     * @param string $layout
     *
     * @return Swift_Message
     *
     * @throws Exception
     * @throws SmartyException
     */

    public static function createMessage($to, $subject, $body, $from = null, $files = array(), $layout = 'bienvenue')
    {

        if (is_null($from)) {
            $from = array(Boutique::getInstance()->contactEmail => Boutique::getInstance()->nom);
        }

        if (!empty($layout)) {
            $smarty = new SiteSmarty();

            $siteUrl =  Tools::transformUrlWithAuthHttp(SITE_URL);

            $smarty->assign('siteUrl', $siteUrl);
            $smarty->assign('content_mail', $body);
            $body = $smarty->fetch('mail/'.$layout.'.tpl');
        }

        $message = Swift_Message::newInstance($subject)
            ->setFrom($from)
            ->setTo($to)
            ->setBody($body)
            ->setContentType("text/html");

        if (!empty($files)) {
            $dir = STORAGE_DIR . "tmp/";
            if (false == is_dir($dir)) {
                mkdir($dir, 0775, true);
            }
            foreach ($files as $file) {
                if (strpos($file[0], "http://") !== false) {
                    if (getenv('HTACCESS') && (strpos($file[0], getenv('HTACCESS')) == false)) {
                        $file[0] = str_replace(Boutique::getInstance()->domaine, getenv('HTACCESS') . Boutique::getInstance()->domaine, $file[0]);
                    }
                    $fileContent = file_get_contents($file[0]);
                    if ($fileContent !== false) {
                        $path = $dir . $file[1];
                        file_put_contents($path, $fileContent);
                    } else {
                        continue;
                    }
                } else {
                    $path = $file[0];
                }
                $message->attach(
                    Swift_Attachment::fromPath($path)->setFilename($file[1])
                );
            }
        }

        return $message;
    }
}
